# README

`CupidPython` contains Python code to compute the equilibrium and to
estimate the parameters in separable one-to-one, bipartite matching
models with perfectly transferable utility---see [Galichon and Salanié
2021](https://econ.columbia.edu/working-paper/cupids-invisible-hand-social-surplus-and-identification-in-matching-models-2/)
for a general study.

It contains:

-   in `ipfp_solvers.py`{.interpreted-text role="mod"}: implementations
    of the Iterative Projection Fitting Procedure (IPFP) algorithm for
    several variants and extensions of the [Choo and Siow
    2006](https://www.jstor.org/stable/10.1086/498585?seq=1) model and for
    a class of nested logit models.
-   in `poisson_glm.py`{.interpreted-text role="mod"}: a function that
    estimates the original version of the Choo and Siow model
    (homoskedastic, with singles) for a semilinear surplus, using
    Poisson GLM.
-   in `min_distance.py`{.interpreted-text role="mod"}: a function that
    applies a minimum distance estimator to separable, semilinear models
    with a user-supplied entropy function.

I also created a [Streamlit](https://www.streamlit.io/) app that
demonstrates the basic Choo and Siow model. You can find a (hopefully)
working version of the app [here](https://share.streamlit.io/bsalanie/cupidpython/main/cupid_streamlit.py).

This package is released under the [MIT license](LICENSE). I hope it is
useful to you.

Bernard Salanié --- Nov 7, 2021

bsalanie at columbia.edu
