# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cupidpython', 'cupidpython.docs', 'cupidpython.docs.source']

package_data = \
{'': ['*'],
 'cupidpython': ['.idea/*', '.idea/inspectionProfiles/*'],
 'cupidpython.docs': ['build/doctrees/*',
                      'build/html/*',
                      'build/html/_images/math/*',
                      'build/html/_sources/*',
                      'build/html/_static/*',
                      'build/html/_static/css/*',
                      'build/html/_static/css/fonts/*',
                      'build/html/_static/js/*',
                      'build/latex/*']}

install_requires = \
['altair>=4.0,<5.0',
 'numpy>=1.15,<2.0',
 'pandas>=1.0,<2.0',
 'scikit-learn>=0.24,<0.25',
 'scipy>=1.3,<2.0',
 'streamlit>=1.0,<2.0',
 'wheel>=0.33,<0.34']

setup_kwargs = {
    'name': 'cupidpython',
    'version': '0.1.8',
    'description': 'Matching with transferable utility',
    'long_description': '# README\n\n`CupidPython` contains Python code to compute the equilibrium and to\nestimate the parameters in separable one-to-one, bipartite matching\nmodels with perfectly transferable utility---see [Galichon and Salanié\n2021](https://econ.columbia.edu/working-paper/cupids-invisible-hand-social-surplus-and-identification-in-matching-models-2/)\nfor a general study.\n\nIt contains:\n\n-   in `ipfp_solvers.py`{.interpreted-text role="mod"}: implementations\n    of the Iterative Projection Fitting Procedure (IPFP) algorithm for\n    several variants and extensions of the [Choo and Siow\n    2006](https://www.jstor.org/stable/10.1086/498585?seq=1) model and for\n    a class of nested logit models.\n-   in `poisson_glm.py`{.interpreted-text role="mod"}: a function that\n    estimates the original version of the Choo and Siow model\n    (homoskedastic, with singles) for a semilinear surplus, using\n    Poisson GLM.\n-   in `min_distance.py`{.interpreted-text role="mod"}: a function that\n    applies a minimum distance estimator to separable, semilinear models\n    with a user-supplied entropy function.\n\nI also created a [Streamlit](https://www.streamlit.io/) app that\ndemonstrates the basic Choo and Siow model. You can find a (hopefully)\nworking version of the app [here](https://share.streamlit.io/bsalanie/cupidpython/main/cupid_streamlit.py).\n\nThis package is released under the [MIT license](LICENSE). I hope it is\nuseful to you.\n\nBernard Salanié --- Nov 7, 2021\n\nbsalanie at columbia.edu\n',
    'author': 'Bernard Salanie',
    'author_email': 'bsalanie@columbia.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bsalanie/CupidPython.git',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.1,<4.0',
}


setup(**setup_kwargs)
